@@ -1,4 +1,7 @@
 package Message::Stack::FormValidator;
+BEGIN {
+  $Message::Stack::FormValidator::VERSION = '0.04';
+}
 use Moose;
 
 use Message::Stack::Message;
@@ -32,3 +35,28 @@ sub parse {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Message::Stack::FormValidator
+
+=head1 VERSION
+
+version 0.04
+
+=head1 AUTHOR
+
+Cory G Watson <gphat@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
